local ActivityRuleLayer5 = class("ActivityRuleLayer5", cc.Layer)

local resFileName = "activities/uibehave_3/activity_rule_3.csb"

function ActivityRuleLayer5:ctor(super, activity)
    self._activityInfo = activity
    self:loadUI()
end

function ActivityRuleLayer5:loadUI()
    self._rootNode = cc.CSLoader:createNode(resFileName)

    if self._rootNode == nil then
        return
    end
    self._rootNode:setContentSize(cc.Director:getInstance():getWinSize())
    ccui.Helper:doLayout(self._rootNode)
    self:addChild(self._rootNode)
    
    self._bg = theGameClientLibUtil:seekChildByName(self._rootNode, "activity_panel")
    local timeText = theGameClientLibUtil:seekChildByName(self._rootNode, "time_range")
    if self._activityInfo.activityTimeText ~= nil then
        timeText:setText(self._activityInfo.activityTimeText)
    end
    
    local gameRoomText = theGameClientLibUtil:seekChildByName(self._rootNode, "process_title_game_name")
    if self._activityInfo.activityTimeText ~= nil then
        gameRoomText:setText(self._activityInfo.gameRoomText)
    else
        gameRoomText:setText("")
    end
    local x,y = gameRoomText:getPosition()
    
    local condition = theGameClientLibUtil:seekChildByName(self._rootNode, "process_title_2")
    if self._activityInfo.activityTimeText ~= nil then
        condition:setText(self._activityInfo.condition)
    else
        condition:setText("")
    end
    x = x + gameRoomText:getContentSize().width
    condition:setPosition(cc.p(x, y))
    
    self._processText = theGameClientLibUtil:seekChildByName(self._rootNode, "process_text")
    x = x + condition:getContentSize().width
    self._processText:setPosition(cc.p(x, y))
    
    self._helpPanel = theGameClientLibUtil:seekChildByName(self._rootNode, "help_bg")
    self._helpPanel:setVisible(false)
    local helpText = theGameClientLibUtil:seekChildByName(self._rootNode, "help_text")
    helpText:setText(self._activityInfo.help)
    
    local helpBtn = theGameClientLibUtil:seekChildByName(self._rootNode, "help_btn")
    helpBtn:addClickEventListener(function(sender)self:onHelpBtnClicked()end)
    x = x + self._processText:getContentSize().width
    helpBtn:setPosition(cc.p(x, y))
    
    self._rewardBtn = theGameClientLibUtil:seekChildByName(self._rootNode, "get_reward_btn")
    self._rewardBtn:setEnabled(false)
        
    local function onTouchBegin(touch, event)
        return true
    end
    
    local function onTouchEnded(touch, event)
        if self.onTouchEnded then
            self:onTouchEnded(touch, event)
        end
    end

    self._listener = cc.EventListenerTouchOneByOne:create()
    self._listener:registerScriptHandler(onTouchBegin, cc.Handler.EVENT_TOUCH_BEGAN)
    self._listener:registerScriptHandler(onTouchEnded, cc.Handler.EVENT_TOUCH_ENDED)
    self:getEventDispatcher():addEventListenerWithSceneGraphPriority(self._listener, self)
    
    self._processBar = theGameClientLibUtil:seekChildByName(self._rootNode, "process")
    self._processBar:setPercent(0)
    self._progressBoxOpened = theGameClientLibUtil:seekChildByName(self._processBar, "reward_btn_have_got")
    self._progressBoxOpenedModule = self._progressBoxOpened:clone()
    self._progressBoxOpenedModule:retain()
    self._progressBoxClosed = theGameClientLibUtil:seekChildByName(self._processBar, "reward_btn_not_get")
    self._progressBoxClosedModule = self._progressBoxClosed:clone()
    self._progressBoxClosedModule:retain()
    self._processBar:removeAllChildren()
    
    self._rewardList = theGameClientLibUtil:seekChildByName(self._rootNode, "reward_list")
    local rewardItem = self._rewardList:getItem(0)
    self._rewardList:setItemModel(rewardItem)
    self._rewardList:removeAllChildren()
    self._rewardList:setScrollBarEnabled(false)

    theHallEventMgr:registerUiHandler(tonumber(self._activityInfo.activityId.."1"), self, handler(self, self.handleGetTeskList))
    theHallEventMgr:registerUiHandler(tonumber(self._activityInfo.activityId.."2"), self, handler(self, self.handleGetRewardCallback)) 
    self._gameId = 0
    if self._activityInfo.gameId == nil or self._activityInfo.gameId  == "" then
        self._gameId = theConfigMgr:GetGameId()
    else
        self._gameId = self._activityInfo.gameId
    end
    local parameter = string.format("GameId=%d&Type=6", self._gameId)
    self:requestGetActivity(self._activityInfo.urlId, parameter, tonumber(self._activityInfo.activityId.."1"))

	if HallEventType.EVENT_ACTIVITY_CHANGED ~= nil then
		theHallEventMgr:registerUiHandler(HallEventType.EVENT_ACTIVITY_CHANGED, self, handler(self, self.onClose))
	end
end

function ActivityRuleLayer5:onClose()
    self._progressBoxClosedModule:release()
    self._progressBoxOpenedModule:release()
    self._helpPanel:setVisible(false)
    theHallEventMgr:removeUiHandler(self)
end

function ActivityRuleLayer5:formatProcessBarBtn()
    local count = #self._processBtns
    if count <= 0 then
        return
    end
    local sz = self._processBar:getContentSize()
    local length = sz.width / count
    
    local x,y = self._processBar:getPosition()
    
    for i = 1,count do
        self._processBtns[i].btn:setPosition(cc.p(length*i, sz.height/2))
    end
end

function ActivityRuleLayer5:onProcessBtnClicked(id)
    if self._currentItemId == id then
        return
    end
    local triangle
    if self._currentItemId > 0 then
        triangle = theGameClientLibUtil:seekChildByName(self._processBtns[self._currentItemId].btn, "triangle")
        triangle:setVisible(false)
    end
    
    triangle = theGameClientLibUtil:seekChildByName(self._processBtns[id].btn, "triangle")
    triangle:setVisible(true)
    self._currentItemId = id
    self._rewardList:removeAllChildren()
    local packageItem = self._rewards[id].PackageItem or {}
    if next(packageItem) == nil then
        self._rewardList:pushBackDefaultItem()
        local item = self._rewardList:getItem(0)
        local itemIcon = theGameClientLibUtil:seekChildByName(item, "reward_item_img")
        local textInfo = theGameClientLibUtil:seekChildByName(item, "reward_text")
        local iconPath = "activities/uibehave_3/images/process_activity/box_fever_"..id..".png"
        if cc.FileUtils:getInstance():isFileExist(iconPath) == false then
            iconPath = "activities/uibehave_3/images/process_activity/box_fever.png"
        end
        itemIcon:loadTexture(iconPath)
        textInfo:setString(self._rewards[id].Name)
    else
        for k,v in pairs(packageItem) do
            self._rewardList:pushBackDefaultItem()
            local item = self._rewardList:getItem(k - 1)
            local itemIcon = theGameClientLibUtil:seekChildByName(item, "reward_item_img")
            local textInfo = theGameClientLibUtil:seekChildByName(item, "reward_text")
            if v.PackageType == 11 then
                itemIcon:loadTexture("images/Task3/diamond.png")
                itemIcon:ignoreContentAdaptWithSize(true)
                textInfo:setString(v.Param1..ClientString.STRING_SCORE_TYPE_DIAMOND)
            elseif v.PackageType == 0 then
                itemIcon:loadTexture("images/Task3/wealth.png")
                itemIcon:ignoreContentAdaptWithSize(true)
                textInfo:setString(v.Param1..ClientString.STRING_SCORE_TYPE_WEALTH)
            elseif v.PackageType == 2 then
                local iconPath = string.format("images/addin/package/%03d.png", v.Param1)
                if cc.FileUtils:getInstance():isFileExist(iconPath) == false then
                    iconPath = "images/Package3/default.png"
                end
                itemIcon:loadTexture(iconPath)
                local strName = v.Name
                if theObjectMgr:FindItemPrototype(v.Param1) ~= nil then
                    strName = theObjectMgr:FindItemPrototype(v.Param1).name
                end
                textInfo:setString(strName)
            else
                itemIcon:loadTexture("images/Package3/default.png")
                textInfo:setString(v.Name)
            end
        end
    end
    
    self._processText:setText("("..self._event[id].CurrentCount.."/"..self._event[id].EventCount..")")
    
    if self._rewards[id].Status == 2 then --0: unreceived 1：received 2：success 3：giveup 4：failed
        self._rewardBtn:loadTextureNormal("activities/uibehave_3/images/process_activity/not_get_btn.png")
        self._rewardBtn:setEnabled(not self._rewards[id].Rewarded)
        self._rewardBtn:addClickEventListener(function(sender) self:onGetRewardBtnClicked(id) end)
    else
        self._rewardBtn:loadTextureNormal("activities/uibehave_3/images/process_activity/goto_play_btn.png")
        self._rewardBtn:setEnabled(true)
        self._rewardBtn:addClickEventListener(function(sender) self:onGotoPlayBtnClicked() end)
    end
end

function ActivityRuleLayer5:onGotoPlayBtnClicked()
    self:onClose()
    url = "k7game://goto_game?gameid="..self._gameId
    theK7ClientLogic:processAppUrl(url)
end

function ActivityRuleLayer5:onGetRewardBtnClicked(id)
    local questId = self._rewards[id].TaskId
    self._rewardBtn:setEnabled(false)
    self._rewards[id].Rewarded = true
    local parameter = string.format("GameId=%d&Type=6&QuestId=%d", self._gameId, questId)
    self:requestPostActivity(self._activityInfo.urlId, parameter, tonumber(self._activityInfo.activityId.."2"))
end

function ActivityRuleLayer5:handleGetRewardCallback(requestSucceed, output)
    if not requestSucceed or output == nil then
        ToastLayer:show(ClientString.STRING_FAILED_TO_GET_DATA)
        return
    end
    
    if next(output) ~= nil and output.IsSuccess then
        self:showRewardLayer(output)
    else
        local tempMsg
        if msg.Message and msg.Message ~= "" then
            tempMsg = output.Message
        else
            tempMsg = ClientString.STRING_FAILED_TO_GET_DATA
        end
        ToastLayer:show(tempMsg)
    end
end

function ActivityRuleLayer5:showRewardLayer(msg)
    local strWealth = nil
    local iconPath = nil
    local strName = nil
    local items = msg.Items or {}
    local reward = {}

    if next(items) == nil then  --金蛋、钻石、奖券
        return
        --theGameClientLibUtil:rewardConfig(reward, strWealth, iconPath, strName)
    else--其他礼包物品
        for i,item in pairs(items) do -- 物品类型
            if item.ItemType == 0 then 
                iconPath = "images/Task3/wealth.png"
                strWealth = item.ItemCount
                strName = ClientString.STRING_SCORE_TYPE_WEALTH
            elseif item.ItemType == 11 then
                iconPath = "images/Task3/diamond.png"
                strWealth = item.ItemCount                       
                strName = ClientString.STRING_SCORE_TYPE_DIAMOND
            elseif item.ItemType == 4 then
                iconPath = "images/Misc3/ticket_img.png"
                strWealth = item.ItemCount                       
                strName = "奖券"
            elseif item.ItemType == 2 then
                iconPath = string.format("images/addin/package/%03d.png", item.ItemId)
                strWealth = item.ItemCount
                if iconPath ~= nil  then
                    if cc.FileUtils:getInstance():isFileExist(iconPath) == false then
                        iconPath = "images/Package3/default.png"
                    end
                end
                if theObjectMgr:FindItemPrototype(item.ItemId) ~= nil then
                    strName = theObjectMgr:FindItemPrototype(item.ItemId).name
                else
                    strName = item.ItemName
                end
            else
                iconPath = "images/Package3/default.png"
                strWealth = item.ItemCount
                strName = item.ItemName
            end
            theGameClientLibUtil:rewardConfig(reward, strWealth, iconPath, strName)
        end
    end

    local ReceiveRewardsLayer = require("hall.uibehave_3.ui.ReceiveRewardsLayer")
    local obj = ReceiveRewardsLayer.new(nil, reward)
    if obj then
        display.getRunningScene():addChild(obj)
    end
end

function ActivityRuleLayer5:setProcessPercent(score)
    if not (tonumber(score) > 0) then
        return 0
    end
    local percent = 0
    local partPercent = 100 / #self._processBtns
    local partBaseScore = 0
    for k,v in pairs(self._processBtns) do
        if score >= v.demand then
            percent = percent + partPercent
        else
            percent = percent + ((score - partBaseScore) / (v.demand - partBaseScore) * partPercent)
            break
        end
        partBaseScore = v.demand
    end
    self._processBar:setPercent(percent)
end

function ActivityRuleLayer5:onHelpBtnClicked()
    self._helpPanel:setVisible(true)
end

function ActivityRuleLayer5:onTouchEnded(touch, event)
    local point = touch:getLocation()
    local boundingBox = self._helpPanel:getBoundingBox()
    if not cc.rectContainsPoint(boundingBox, point) and self._helpPanel:isVisible() then
        self._helpPanel:setVisible(false)
    end
end

function ActivityRuleLayer5:handleGetTeskList(requestSucceed, output)
    self._event = {}
    if requestSucceed and next(output) ~= nil and output.IsSuccess ~= false then
        self._processBtns = {}
        self._rewards = {}
        local score = 0
        local eventCount = 0
        for k,v in pairs(output) do
            local event = v.Events[1]
            local btnInfo = {}
            local item = self._progressBoxClosedModule:clone()
            self._processBar:addChild(item)
            btnInfo["btn"] = item
            btnInfo["demand"] = event.EventCount
            self._processBtns[k] = btnInfo
            score = event.CurrentCount
            eventCount = event.EventCount
            self._event[k] = event
            triangle = theGameClientLibUtil:seekChildByName(self._processBtns[k].btn, "triangle")
            triangle:setVisible(false)
            local imgPath = "activities/uibehave_3/images/process_activity/"
            if v.Rewarded then
                img = imgPath .. "reward_btn_2.png"
            else
                img = imgPath .. "reward_btn_1.png"
            end
                self._processBtns[k].btn:loadTextureNormal(img)
            v.Package["Rewarded"] = v.Rewarded
            v.Package["Status"] = v.Status
            v.Package["TaskId"] = v.TaskId
            self._rewards[k] = v.Package
        end
        self._processText:setText("("..score.."/"..eventCount..")")
        self:setProcessPercent(score)
        self._currentItemId = 0
        self:onProcessBtnClicked(1)
        for k,v in pairs(self._processBtns) do
            v.btn:addClickEventListener(function(sender)self:onProcessBtnClicked(k)end)
        end
        self:formatProcessBarBtn()
        
    end
end

function ActivityRuleLayer5:requestGetActivity(urlId, parameters, eventId)
	local url = theConfigMgr:GetUrl(ConfigUrlIndex.CONFIG_URL_API_DOMAIN, true)..string.format("/v2/Activity/%d?Uid=%d&Key=%s&AppId=%d",urlId, theMyself:GetId(), theMyself:GetSessionKey(), theConfigMgr:GetAppId())
	if parameters ~= nil or parameters ~= "" then
		url = url .."&" .. parameters
	end
    theK7ApiClientLua:getDataFromUrl(url,
    function(requestSucceed, output)
        theHallEventMgr:sendUiHandler(eventId, requestSucceed, output)
    end)
end

function ActivityRuleLayer5:requestPostActivity(urlId, parameters, eventId)
    local url = theConfigMgr:GetUrl(ConfigUrlIndex.CONFIG_URL_API_DOMAIN, true).."/v2/Activity/"..urlId
    local data = string.format("Uid=%d&Key=%s&AppId=%d",
        theMyself:GetId(), theMyself:GetSessionKey(), theConfigMgr:GetAppId())
	if parameters ~= nil or parameters ~= "" then
		data = data .."&".. parameters
	end
    theK7ApiClientLua:postDataFromUrl(url,
    function(requestSucceed, output)
        theHallEventMgr:sendUiHandler(eventId, requestSucceed, output)
    end,
    data)
end

return ActivityRuleLayer5