local GameBoxRuleLayer242 =class("GameBoxRuleLayer242",cc.Layer)

local resFileName = "rules/uibehave_3/game_box_rule_242.csb"

GameBoxRuleLayer242.Price_AA = {
    [4] = 1,
    [8] = 2,
    [12] = 3
}
GameBoxRuleLayer242.Price_FangZhu = {
    [4] = 4,
    [8] = 7,
    [12] = 10
}
GameBoxRuleLayer242.PayMode = {
    Pay_Owner = 0,
    Pay_AA = 1
}
function GameBoxRuleLayer242:ctor(super)
    self._gameID = 242

    self._createOption = {
		EnableSwap = 1
    }
	self._roundValue = 4
    self._pay_rule = self.PayMode.Pay_Owner -- 0 房主承包 1.AA
	self:loadLocalOptions()
    self:loadUI()
end

function GameBoxRuleLayer242:loadUI()

    local isExist =  cc.FileUtils:getInstance():isFileExist(resFileName)
    if(isExist == false) then
        return
    end
    self._m_rootNode = cc.CSLoader:createNode(resFileName)
    self:addChild(self._m_rootNode)
	
    self._bg = self._m_rootNode:getChildByName("setting_bg");

    self._round_checkBox_0 = ccui.Helper:seekWidgetByName(self._bg, "round_checkBox_0");
	self._round_checkBox_0:setSelected(true)
	self._selectedRoundName = "round_checkBox_0"

    self._round_checkBox_1 = ccui.Helper:seekWidgetByName(self._bg, "round_checkBox_1");
	self._round_checkBox_1:setSelected(false)
    self._round_checkBox_2 = ccui.Helper:seekWidgetByName(self._bg, "round_checkBox_2");
	self._round_checkBox_2:setSelected(false)
    self._roomcard_label   = ccui.Helper:seekWidgetByName(self._bg, "roomcard_label");
    self._roomcard_tip   = self._roomcard_label:getChildByName("tip")
	
	if self._roundValue == 4 then
        self._selectedRoundName = "round_checkBox_0"
        self._round_checkBox_0:setSelected(true)
        self._round_checkBox_1:setSelected(false)
        self._round_checkBox_2:setSelected(false)
    elseif self._roundValue == 8 then
        self._selectedRoundName = "round_checkBox_1"
        self._round_checkBox_0:setSelected(false)
        self._round_checkBox_1:setSelected(true)
        self._round_checkBox_2:setSelected(false)
    elseif self._roundValue == 12 then
        self._selectedRoundName = "round_checkBox_2"
        self._round_checkBox_0:setSelected(false)
        self._round_checkBox_1:setSelected(false)
        self._round_checkBox_2:setSelected(true)
    end
    self:setRound(self._roundValue)

      self._round_checkBox_0:addEventListener(
        function(sender,eventType)
           self:onRoundChecked(sender,eventType)
           self:setRound(4)
        end
    )

      self._round_checkBox_1:addEventListener(
        function(sender,eventType)
           self:onRoundChecked(sender,eventType)
		   self:setRound(8)
        end
    )

      self._round_checkBox_2:addEventListener(
        function(sender,eventType)
           self:onRoundChecked(sender,eventType)
		   self:setRound(12)
        end
    )

    self:loadOptions()
    self:loadPayOptions()
end

function GameBoxRuleLayer242:loadOptions()
    self._opt_checkBox_swap = ccui.Helper:seekWidgetByName(self._bg, "opt_checkBox_swap");
	self._opt_checkBox_swap:setSelected(self._createOption.EnableSwap == 1)
	self._opt_checkBox_swap:addEventListener(
        function(sender,eventType)
			if eventType == ccui.CheckBoxEventType.selected then
                self._createOption.EnableSwap = 1
            else
                self._createOption.EnableSwap = 0
            end
        end
    )
end
function GameBoxRuleLayer242:loadPayOptions()
    self._pay_checkBox_0 = ccui.Helper:seekWidgetByName(self._bg, "pay_checkBox_0"); -- 房主
    self._pay_checkBox_1 = ccui.Helper:seekWidgetByName(self._bg, "pay_checkBox_1"); -- AA
	
	if self._pay_rule == self.PayMode.Pay_Owner then
        self._pay_checkBox_0:setSelected(true)
	    self._pay_checkBox_1:setSelected(false)
    else
        self._pay_checkBox_0:setSelected(false)
	    self._pay_checkBox_1:setSelected(true)
    end

    self._pay_checkBox_0:addEventListener(
        function(sender,eventType)
			if eventType == ccui.CheckBoxEventType.selected then
                self._pay_checkBox_1:setSelected(false)
                self._pay_rule = self.PayMode.Pay_Owner
                self:setRound(self._roundValue)
            else
                self._pay_checkBox_0:setSelected(true)
                self._pay_checkBox_1:setSelected(false)
            end
        end
    )

    self._pay_checkBox_1:addEventListener(
        function(sender,eventType)
			if eventType == ccui.CheckBoxEventType.selected then
                self._pay_checkBox_0:setSelected(false)
                self._pay_rule = self.PayMode.Pay_AA
                self:setRound(self._roundValue)
            else
                self._pay_checkBox_0:setSelected(false)
                self._pay_checkBox_1:setSelected(true)
            end
        end
    )
end

function GameBoxRuleLayer242:setRound(round)
    self._roundValue = round
    local cost = 0
    if self._pay_rule == self.PayMode.Pay_Owner then
        cost = self.Price_FangZhu[round]
    else
        cost = self.Price_AA[round]
    end
    self._roomcard_label:setString(cost)
    self._roomcard_tip:setVisible(theMyself:GetDiamond() < cost)
	if theMyself:GetDiamond() < cost then
		self._roomcard_label:setTextColor(ccc3(255,64,64))
	else
		self._roomcard_label:setTextColor(ccc3(71,191,60))
	end

end

function GameBoxRuleLayer242:onRoundChecked(sender,eventType)
    sender:setSelected(true)
	local name = sender:getName()
	if (name ~= self._selectedRoundName) then
		self._round_checkBox_select = ccui.Helper:seekWidgetByName(self._bg, self._selectedRoundName);
		self._round_checkBox_select:setSelected(false);
		self._selectedRoundName = name
	end
end

function GameBoxRuleLayer242:getCreateBoxInfo()
    local info = {}
    info.boxRound = self._roundValue
    info.baseScore = 1
	info.duration = 0
	info.payRule = self._pay_rule
	info.options = self:getOptions()  
	self:saveLocalOptions(info.options)
	return info
end

function GameBoxRuleLayer242:getOptions()
    local opt = {}
    for k,v in pairs(self._createOption) do
        table.insert(opt,k.."="..v)
    end
	table.insert(opt,"PayRule="..self._pay_rule)
    return table.concat(opt,",")
end

function GameBoxRuleLayer242:saveLocalOptions(opts)
	local localOpts = opts..(",boxRound="..self._roundValue)
    cc.UserDefault:getInstance():setStringForKey("opt242",opts)
    cc.UserDefault:getInstance():flush()
end

function GameBoxRuleLayer242:loadLocalOptions()
	local opts = cc.UserDefault:getInstance():getStringForKey("opt242","")
    if string.len(opts) == 0 then
        return
    end
    local opts = string.split(opts, ",")
    for i = 1,#opts do
        local opt = opts[i]
        local pos = string.find(opt, "=")
        if pos > 1 then
            local key = string.sub(opt,1,pos-1)
            local value = string.sub(opt,pos+1,-1)
            if self._createOption[key] then
                self._createOption[key] = tonumber(value)
            else
                if key == "boxRound" then
                    self._roundValue = tonumber(value)
                elseif key == "PayRule" then
                    self._pay_rule = tonumber(value)
                end
            end
        end
    end
end

function GameBoxRuleLayer242:getBtnImgs()
    return self._ruleBtnNormal, self._ruleBtnSelect, self._ruleBtnDisable
end

return GameBoxRuleLayer242
